pub enum GeneralConstId<'db> {
ConstId(ConstId),
StaticId(StaticId),
AnonConstId(AnonConstId<'db>),
}Expand description
A constant, which might appears as a const item, an anonymous const block in expressions or patterns, or as a constant in types with const generics.
Variants
Implementations
Sourceimpl<'db> GeneralConstId<'db>
impl<'db> GeneralConstId<'db>
pub fn generic_def(self, db: &'db dyn HirDatabase) -> Option<GenericDefId>
pub fn name(self, db: &'db dyn SourceDatabase) -> String